# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
import pydantic
from .environment_deployment_config_revision_lookup import EnvironmentDeploymentConfigRevisionLookup
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class EnvironmentDeploymentConfig(UncheckedBaseModel):
    revision_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Revision ID to direct traffic to
    """

    revision_lookup: EnvironmentDeploymentConfigRevisionLookup
    traffic: typing.Optional[int] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
